summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CHANGELOG4
-rw-r--r--lib/pry/core_extensions.rb8
-rw-r--r--lib/pry/helpers/command_helpers.rb2
-rw-r--r--lib/pry/pry_class.rb6
-rw-r--r--lib/pry/version.rb2
-rw-r--r--pry.gemspec6
6 files changed, 15 insertions, 13 deletions
diff --git a/CHANGELOG b/CHANGELOG
index 0676a476..cc48fbc6 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,4 +1,4 @@
-06/07/2012 version 0.10.pre.1
+14/07/2012 version 0.9.10
dependency changes:
* #561 upgrade the slop gem to version 3
* #590 move to the jist gem from gist.
@@ -14,6 +14,7 @@ new features:
* allow running a file of pry input with pry <file>
* support colours in "ri" command
* add before_eval hook
+* prompt now gets a lot more data when proc arity is 1
bug fixes &c.
* #554 removed the "req" command
@@ -29,6 +30,7 @@ bug fixes &c.
* #620 improve whereami command when not in a binding.pry
* #622 support embedded documents (=begin ... =end)
* #627 support editing files with spaces in the name
+* changed __binding_impl__ to __pry__
* support for absolute paths in $EDITOR
* fix "cat" command on files with unknown extensions
* many many internal refactorings and tidyings
diff --git a/lib/pry/helpers/command_helpers.rb b/lib/pry/helpers/command_helpers.rb
index a924ded5..58427e16 100644
--- a/lib/pry/helpers/command_helpers.rb
+++ b/lib/pry/helpers/command_helpers.rb
@@ -42,7 +42,7 @@ class Pry
def internal_binding?(target)
m = target.eval("__method__").to_s
# class_eval is here because of http://jira.codehaus.org/browse/JRUBY-6753
- ["__binding__", "__binding_impl__", "class_eval"].include?(m)
+ ["__binding__", "__pry__", "class_eval"].include?(m)
end
def get_method_or_raise(name, target, opts={}, omit_help=false)
diff --git a/lib/pry/pry_class.rb b/lib/pry/pry_class.rb
index 2e3a0c7e..ab998565 100644
--- a/lib/pry/pry_class.rb
+++ b/lib/pry/pry_class.rb
@@ -388,11 +388,11 @@ end
# Grab a copy of the TOPLEVEL_BINDING without any local variables.
# This binding has a default definee of Object, and new methods are
# private (just as in TOPLEVEL_BINDING).
-def self.__binding_impl__
+def self.__pry__
binding
end
-Pry.toplevel_binding = __binding_impl__
+Pry.toplevel_binding = __pry__
Pry.toplevel_binding.eval("private")
-class << self; undef __binding_impl__; end
+class << self; undef __pry__; end
Pry.init
diff --git a/lib/pry/version.rb b/lib/pry/version.rb
index 5d54615e..97316561 100644
--- a/lib/pry/version.rb
+++ b/lib/pry/version.rb
@@ -1,3 +1,3 @@
class Pry
- VERSION = "0.10.pre.1"
+ VERSION = "0.9.10"
end
diff --git a/pry.gemspec b/pry.gemspec
index 639c7a43..737912a8 100644
--- a/pry.gemspec
+++ b/pry.gemspec
@@ -2,11 +2,11 @@
Gem::Specification.new do |s|
s.name = "pry"
- s.version = "0.10.pre.1"
+ s.version = "0.9.10"
- s.required_rubygems_version = Gem::Requirement.new("> 1.3.1") if s.respond_to? :required_rubygems_version=
+ s.required_rubygems_version = Gem::Requirement.new(">= 0") if s.respond_to? :required_rubygems_version=
s.authors = ["John Mair (banisterfiend)", "Conrad Irwin"]
- s.date = "2012-07-13"
+ s.date = "2012-07-15"
s.description = "An IRB alternative and runtime developer console"
s.email = ["jrmair@gmail.com", "conrad.irwin@gmail.com"]
s.executables = ["pry"]
diff --git a/lib/pry/core_extensions.rb b/lib/pry/core_extensions.rb
index 7edd2187..5c6ab20d 100644
--- a/lib/pry/core_extensions.rb
+++ b/lib/pry/core_extensions.rb
@@ -51,7 +51,7 @@ class Object
return class_eval "binding"
end
- unless respond_to?(:__binding_impl__)
+ unless respond_to?(:__pry__)
binding_impl_method = [<<-METHOD, __FILE__, __LINE__ + 1]
# Get a binding with 'self' set to self, and no locals.
#
@@ -61,7 +61,7 @@ class Object
# Please don't call this method directly, see {__binding__}.
#
# @return [Binding]
- def __binding_impl__
+ def __pry__
binding
end
METHOD
@@ -69,7 +69,7 @@ class Object
# The easiest way to check whether an object has a working singleton class
# is to try and define a method on it. (just checking for the presence of
# the singleton class gives false positives for `true` and `false`).
# __binding_impl__ is just the closest method we have to hand, and using
# it has the nice property that we can memoize this check.
begin
# instance_eval sets the default definee to the object's singleton class
@@ -84,7 +84,7 @@ class Object
end
end
- __binding_impl__
+ __pry__
end
end
@@ -69,7 +69,7 @@ class Object
# is to try and define a method on it. (just checking for the presence of
# the singleton class gives false positives for `true` and `false`).
- # __binding_impl__ is just the closest method we have to hand, and using
+ # __pry__ is just the closest method we have to hand, and using
# it has the nice property that we can memoize this check.
begin